.TH "cmscore" 1 "December 2005" "Infernal 0.7" "Infernal Manual"

.SH NAME
.TP 
cmscore - align and score one or more sequences to a CM

.SH SYNOPSIS
.B cmscore
.I [options]
.I cmfile
.I seqfile

.SH DESCRIPTION

.B cmscore
uses the
covariance model (CM) in
.I cmfile
to align and score the sequences in
.I seqfile,
and output the score and optimal alignment for each one.
.B cmscore 
is a testbed 
for new CM alignment algorithms, and it is also used by the testsuite.
It is not intended to be particularly useful in the real world. Documentation
is provided for completeness, and to aid my own memory.

.PP
Currently, 
.B cmscore
aligns the sequence(s) by both the full CYK algorithm and
the divide and conquer variant (SR Eddy, BMC Bioinformatics 3:18,
2002), and outputs both parse trees.


.PP
Usually, the two parse trees should be identical for any sequence.
However, there can be cases of ties, where two or more different parse
trees have identical scores. In such cases, it is possible for the two
parse trees to differ. The parse tree selected as "optimal" from
amongst the ties is arbitrary, dependent on order of evaluation in the
DP traceback, and the order of evaluation for D&C vs. standard CYK is
different. 
Thus, in its testsuite role,
.B cmscore 
checks that the scores are within 0.01 bits of each other, but
does not check that the parse trees are absolutely identical;
identity can be checked for using the
.B --stringent
option.

.PP
The sequence file can be in most any common biosequence format,
including alignment file formats (in which case the sequences
will be read as if they were unaligned). FASTA format is
recommended. 

.PP
The sequences are treated as single stranded RNAs; that is,
only the given strand of each sequence is aligned and scored, and
no reverse complementing is done.

.PP
CM files are profiles of RNA consensus secondary structure. A
CM file is produced by the 
.B cmbuild 
program, from a given RNA sequence alignment of known 
consensus structure.

.SH OPTIONS

.TP
.B -h
Print brief help; includes version number and summary of
all options, including expert options.

.SH EXPERT OPTIONS

.TP
.BI --informat " <s>"
Assert that the input 
.I seqfile
is in format
.I <s>.
Do not run Babelfish format autodection. This increases
the reliability of the program somewhat, because 
the Babelfish can make mistakes; particularly
recommended for unattended, high-throughput runs
of Infernal. 
.I <s>
is case-insensitive;
valid formats include FASTA,
GENBANK, EMBL, GCG, PIR, STOCKHOLM, SELEX, MSF,
CLUSTAL, and PHYLIP. 
See the User's Guide for a complete
list.

.TP
.B --local
Turn on the local alignment algorithm, which allows the alignment
to span two or more subsequences if necessary (e.g. if the structures
of the query model and target sequence are only partially shared),
allowing certain large insertions and deletions in the structure
to be penalized differently than normal indels.
The default is to globally align the query model to the target
sequences.

.TP
.BI --regress " <f>"
Save regression test information to a file
.I <f>. 
This is part of the automated testing procedure at each release. 

.TP
.B --scoreonly
Do the small memory "score only" variant of the standard CYK alignment
algorithm, and don't recover a parse tree. 

.TP
.B --smallonly
Skip the standard CYK algorithm; do only the divide and conquer
algorithm.

.TP
.B --stringent
Require the two parse trees to be identical; fail and return a
non-zero exit code if they are not. Normally, 
.B cmscore 
only requires that the two parse trees have identical scores
(within a floating point tolerance of 0.01 bits), because 
it is possible to have more than one parse tree with the same
score.

.TP 
.B --X
Project X. Undocumented. No serviceable parts inside.
Using this option voids your warranty. Do not attempt.
Professional driver on a closed course. May induce
dizziness and vomiting.






.SH SEE ALSO

For complete documentation, see the User's Guide (Userguide.pdf) that
came with the distribution; or see the Infernal web page,
http://infernal.wustl.edu/.

.SH COPYRIGHT

.nf
Copyright (C) 2001-2005 HHMI/Washington University School of Medicine.
Freely distributed under the GNU General Public License (GPL).
.fi
See the file COPYING that came with the source
for details on redistribution conditions.

.SH AUTHOR

.nf
Sean Eddy
HHMI/Dept. of Genetics
Washington Univ. School of Medicine
4566 Scott Ave.
St Louis, MO 63110 USA
http://www.genetics.wustl.edu/eddy/

